@@ -4,7 +4,7 @@ from copy import deepcopy
 
 # Non standard libraries
 import requests
-
+import io
 from aanalytics2 import config, token_provider
 
 
@@ -21,7 +21,8 @@ class AdobeRequest:
                  verbose: bool = False,
                  retry: int = 0,
                  loggingEnabled:bool=False,
-                 logger:object=None
+                 logger:object=None,
+                 company_id:str=None
                 ) -> None:
         """
         Set the connector to be used for handling request to AAM
@@ -31,7 +32,8 @@ class AdobeRequest:
             verbose : OPTIONAL : display comment on the request.
             retry : OPTIONAL : If you wish to retry failed GET requests
             loggingEnabled : OPTIONAL : if the logging is enable for that instance.
-            logger : OPTIONAL : instance of the logger created 
+            logger : OPTIONAL : instance of the logger created
+            company_id: OPTIONAL : company id to be used for the request
         """
         if config_object['org_id'] == '':
             raise Exception(
@@ -43,15 +45,21 @@ class AdobeRequest:
         self.restTime = 30
         self.retry = retry
         if self.config['token'] == '' or time.time() > self.config['date_limit']:
-            token_and_expiry = token_provider.get_token_and_expiry_for_config(config=self.config, verbose=verbose)
+            if 'scopes' in self.config.keys() and self.config.get('scopes',None) is not None:
+                self.connectionType = 'oauthV2'
+                token_and_expiry = token_provider.get_oauth_token_and_expiry_for_config(config=self.config, verbose=verbose)
+            elif self.config.get("private_key",None) is not None or self.config.get("pathToKey",None) is not None:
+                self.connectionType = 'jwt'
+                token_and_expiry = token_provider.get_jwt_token_and_expiry_for_config(config=self.config, verbose=verbose)
             token = token_and_expiry['token']
             expiry = token_and_expiry['expiry']
             self.token = token
             if self.loggingEnabled:
                 self.logger.info("token retrieved : {token}")
             self.config['token'] = token
-            self.config['date_limit'] = time.time() + expiry / 1000 - 500
+            self.config['date_limit'] = time.time() + expiry - 500
             self.header.update({'Authorization': f'Bearer {token}'})
+            self.header.update({'x-proxy-global-company-id': company_id})
 
     def _checkingDate(self) -> None:
         """
@@ -61,12 +69,15 @@ class AdobeRequest:
         if now > self.config['date_limit']:
             if self.loggingEnabled:
                 self.logger.warning("token expired. Trying to retrieve a new token")
-            token_with_expiry = token_provider.get_token_and_expiry_for_config(config=self.config)
-            token = token_with_expiry['token']
+            if self.connectionType =='oauthV2':
+                token_and_expiry = token_provider.get_oauth_token_and_expiry_for_config(config=self.config)
+            elif self.connectionType == 'jwt':
+                token_and_expiry = token_provider.get_jwt_token_and_expiry_for_config(config=self.config)
+            token = token_and_expiry['token']
             if self.loggingEnabled:
-                self.logger.info("new token retrieved : {token}")
+                self.logger.info(f"new token retrieved : {token}")
             self.config['token'] = token
-            self.config['date_limit'] = time.time() + token_with_expiry['expiry'] / 1000 - 500
+            self.config['date_limit'] = time.time() + token_and_expiry['expiry'] - 500
             self.header.update({'Authorization': f'Bearer {token}'})
 
     def getData(self, endpoint: str, params: dict = None, data: dict = None, headers: dict = None, *args, **kwargs):
@@ -104,11 +115,19 @@ class AdobeRequest:
                 res = requests.get(endpoint, headers=headers, params=params, data=data)
             res_json = res.json()
         except:
-            ## handling 1.4
+            ## handling 1.4 and classification
             if self.loggingEnabled:
                 self.logger.warning(f"handling exception as res.json() cannot be managed")
                 self.logger.warning(f"status code: {res.status_code}")
-            if kwargs.get('legacy',False):
+            if kwargs.get('classFile'): ## reading classification files
+                text = res.text
+                textIO = io.StringIO(text)
+                list_lines = list(textIO.readlines())
+                data = []
+                for line in list_lines:
+                    data.append(json.loads(line.strip()))
+                return data
+            elif kwargs.get('legacy',False): ## handling 1.4
                 try:
                     return json.loads(res.text)
                 except:
@@ -126,26 +145,29 @@ class AdobeRequest:
                     print('Retry parameter activated')
                     print(f'{internRetry} retry left')
                 if 'error' in res_json.keys():
-                    time.sleep(30)
-                    res_json = self.getData(endpoint, params=params, data=data, headers=headers, retry=internRetry-1, **kwargs)
+                    time.sleep(self.restTime)
+                    kwargs["retry"] = internRetry - 1
+                    res_json = self.getData(endpoint, params=params, data=data, headers=headers, **kwargs)
                     return res_json
         return res_json
 
-    def postData(self, endpoint: str, params: dict = None, data: dict = None, headers: dict = None, *args, **kwargs):
+    def postData(self, endpoint: str, params: dict = None, data: dict = None, headers: dict = None, files:dict=None, *args, **kwargs):
         """
         Abstraction for posting data
         """
         self._checkingDate()
+        if params is None:
+            params = {}
         if headers is None:
             headers = self.header
-        if params is None and data is None:
-            res = requests.post(endpoint, headers=headers)
-        elif params is not None and data is None:
-            res = requests.post(endpoint, headers=headers, params=params)
-        elif params is None and data is not None:
-            res = requests.post(endpoint, headers=headers, data=json.dumps(data))
-        elif params is not None and data is not None:
-            res = requests.post(endpoint, headers=headers, params=params, data=json.dumps(data))
+        if data is None and files is None:
+            res = requests.post(endpoint, headers=headers,params=params)
+        elif data is not None and files is None:
+            res = requests.post(endpoint, headers=headers, data=json.dumps(data),params=params)
+        elif data is None and files is not None:
+            res = requests.post(endpoint, headers=headers, params=params, files=files)
+        elif data is not None and files is not None:
+            res = requests.post(endpoint, headers=headers, params=params, data=json.dumps(data), files=files)
         try:
             res_json = res.json()
             if res.status_code == 429 or res_json.get('error_code', None) == "429050":
@@ -162,19 +184,21 @@ class AdobeRequest:
             res_json = {'error': res.get('status_code','Request Error')}
         return res_json
 
-    def patchData(self, endpoint: str, params: dict = None, data=None, headers: dict = None, *args, **kwargs):
+    def patchData(self, endpoint: str, params: dict = None, data:dict = None, headers: dict = None, files : dict = None,  *args, **kwargs):
         """
         Abstraction for patching data
         """
         self._checkingDate()
         if headers is None:
             headers = self.header
-        if params is not None and data is None:
+        if params is not None and data is None and files is None:
             res = requests.patch(endpoint, headers=headers, params=params)
-        elif params is None and data is not None:
+        elif params is None and data is not None and files is None:
             res = requests.patch(endpoint, headers=headers, data=json.dumps(data))
-        elif params is not None and data is not None:
+        elif params is not None and data is not None and files is None:
             res = requests.patch(endpoint, headers=headers, params=params, data=json.dumps(data))
+        elif files is not None:
+            res = requests.patch(endpoint, headers=headers, params=params, files=files)
         try:
             while str(res.status_code) == "429":
                 if kwargs.get("verbose", False):
@@ -188,19 +212,21 @@ class AdobeRequest:
             res_json = {'error': res.get('status_code','Request Error')}
         return res_json
 
-    def putData(self, endpoint: str, params: dict = None, data=None, headers: dict = None, *args, **kwargs):
+    def putData(self, endpoint: str, params: dict = None, data=None, headers: dict = None, files:dict=None,*args, **kwargs):
         """
         Abstraction for putting data
         """
         self._checkingDate()
         if headers is None:
             headers = self.header
-        if params is not None and data is None:
+        if params is not None and data is None and files is None:
             res = requests.put(endpoint, headers=headers, params=params)
-        elif params is None and data is not None:
+        elif params is None and data is not None and files is None:
             res = requests.put(endpoint, headers=headers, data=json.dumps(data))
-        elif params is not None and data is not None:
+        elif params is not None and data is not None and files is None:
             res = requests.put(endpoint, headers=headers, params=params, data=json.dumps(data=data))
+        elif files is not None:
+            res = requests.put(endpoint, headers=headers, params=params, files=files)
         try:
             status_code = res.json()
         except:
