@@ -38,7 +38,7 @@ class Workspace:
             reportType : OPTIONAL : define type of report retrieved.(normal, static, multi)
             metrics : OPTIONAL : dictionary of the columns Id for normal report and list of columns name for Static report
             metricFilters : OPTIONAL : Filter name for the id of the filter
-            resolveColumns : OPTIONAL :
+            resolveColumns : OPTIONAL : If you want to resolve the column name and returning ID instead of name
         """
         for filter in dataRequest["globalFilters"]:
             if filter["type"] == "dateRange":
@@ -55,8 +55,17 @@ class Workspace:
         filters = []
         for filter in dataRequest["globalFilters"]:
             if filter["type"] == "segment":
-                seg = self.analyticsObject.getSegment(filter["segmentId"])
-                filter["segmentName"] = seg["name"]
+                segmentId = filter.get("segmentId",None)
+                if segmentId is not None:
+                    seg = self.analyticsObject.getSegment(filter["segmentId"])
+                    filter["segmentName"] = seg["name"]
+                else:
+                    context = filter.get('segmentDefinition',{}).get('container',{}).get('context')
+                    description = filter.get('segmentDefinition',{}).get('container',{}).get('pred',{}).get('description')
+                    listName = ','.join(filter.get('segmentDefinition',{}).get('container',{}).get('pred',{}).get('list',[]))
+                    function = filter.get('segmentDefinition',{}).get('container',{}).get('pred',{}).get('func')
+                    filter["segmentId"] = f"Dynamic: {context} {description} {function} {listName}"
+                    filter["segmentName"] = f"{context} {description} {listName}"
             filters.append(filter)
         self.globalFilters = filters
         self.metricFilters = metricFilters
@@ -68,12 +77,17 @@ class Workspace:
         if reportType == "normal":
             columns_data = ["itemId"]
         elif reportType == "static":
-            columns_data = ["FilterName"]
+            columns_data = ["SegmentName"]
         ### adding dimensions & metrics in columns names when reportType is "normal"
         if "dimension" in dataRequest.keys() and reportType == "normal":
             columns_data.append(dataRequest["dimension"])
             ### adding metrics in columns names
             columnIds = columns["columnIds"]
+            # To get readable names of template metrics and Success Events, we need to get the full list of metrics for the Report Suite first. 
+            # But we won't do this if there are no such metrics in the report.
+            if (resolveColumns is True) & (
+                    len([metric for metric in metrics.values() if metric.startswith("metrics/")]) > 0):
+                rsMetricsList = self.analyticsObject.getMetrics(rsid=dataRequest["rsid"])
             for col in columnIds:
                 metrics: dict = metrics  ## case when dict is used
                 metricListName: list = metrics[col].split(":::")
@@ -88,6 +102,9 @@ class Workspace:
                             seg = self.analyticsObject.getSegment(metric)
                             segName = seg.get("name",metric)
                             metricResolvedName.append(segName)
+                        elif metric.startswith("metrics/"):
+                            metricName = rsMetricsList[rsMetricsList["id"] == metric]["name"].iloc[0]
+                            metricResolvedName.append(metricName)
                         else:
                             metricResolvedName.append(metric)
                     colName = ":::".join(metricResolvedName)
@@ -96,7 +113,7 @@ class Workspace:
                     columns_data.append(metrics[col])
         elif reportType == "static":
             metrics: list = metrics  ## case when a list is used
-            columns_data.append("FilterId")
+            columns_data.append("SegmentId")
             columns_data += metrics
         if df_init.empty == False and (
             reportType == "static" or reportType == "normal"
@@ -149,7 +166,7 @@ class Workspace:
         """
         if filename is None:
             filename = f"cjapy_{int(time.time())}.csv"
-        self.df_init.to_csv(filename, delimiter=delimiter, index=index)
+        self.dataframe.to_csv(filename, sep=delimiter, index=index)
 
     def to_json(self, filename: str = None, orient: str = "index") -> IO:
         """
@@ -160,7 +177,7 @@ class Workspace:
         """
         if filename is None:
             filename = f"cjapy_{int(time.time())}.json"
-        self.df_init.to_json(filename, orient=orient)
+        self.dataframe.to_json(filename, orient=orient)
 
     def breakdown(
         self,
@@ -177,6 +194,7 @@ class Workspace:
             dimension : REQUIRED : dimension to report.
             n_results : OPTIONAL : number of results you want to have on your breakdown. Default 10, can use "inf"
         """
+        n_results = float(n_results) ## transforming n_result in float
         if index is None or dimension is None:
             raise ValueError(
                 "Require a value to use as breakdown and dimension to request"
